pub fn render_template(template: &str, vars: &TemplateVars) -> StringExpand description
Render template by replacing {{key}} placeholders with values in vars.
This is intentionally simple and avoids complex templating logic.
pub fn render_template(template: &str, vars: &TemplateVars) -> StringRender template by replacing {{key}} placeholders with values in vars.
This is intentionally simple and avoids complex templating logic.